package com.elitesland.item.repo;

import com.elitesland.basic.JpaQueryProcInterface;
import com.elitesland.item.entity.QItmBrandDO;
import com.elitesland.itm.param.ItmBrandQueryParam;
import com.elitesland.itm.vo.ItmBrandVO;
import com.querydsl.core.types.ExpressionUtils;
import com.querydsl.core.types.Predicate;
import com.querydsl.core.types.Projections;
import com.querydsl.jpa.impl.JPAQuery;
import com.querydsl.jpa.impl.JPAQueryFactory;
import lombok.RequiredArgsConstructor;
import lombok.val;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

/**
 * <p>
 * 功能说明
 * </p>
 *
 * @author roman.zhang
 * @since 2020-08-17 14:34:22
 */
@Component
@RequiredArgsConstructor
public class ItmBrandRepoProc implements JpaQueryProcInterface {

    private final JPAQueryFactory jpaQueryFactory;

    /**
     * 查询字段
     */
    public JPAQuery<ItmBrandVO> select(ItmBrandQueryParam param) {
        val jpaQDo = QItmBrandDO.itmBrandDO;
        Predicate predicate = jpaQDo.isNotNull();
        val jpaQuery = jpaQueryFactory.select(Projections.bean(ItmBrandVO.class,
                jpaQDo.id,
                jpaQDo.brandCode,
                jpaQDo.brandName,
                jpaQDo.brandName2,
                jpaQDo.abbrName,
                jpaQDo.brandStatus,
                jpaQDo.brandType,
                jpaQDo.brandType2,
                jpaQDo.brandType3,
                jpaQDo.itemGroup,
                jpaQDo.itemCate,
                jpaQDo.brandPhase,
                jpaQDo.brandLevel,
                jpaQDo.pid,
                jpaQDo.brandPath,
                jpaQDo.agency,
                jpaQDo.managerEmpId
        )).from(jpaQDo);
        if (param != null) {
            jpaQuery.where(where(param));
        }
        return jpaQuery;
    }

    /**
     * 根据主键查询
     *
     * @param id 主键
     */
    public Predicate where(Long id) {
        val jpaQDo = QItmBrandDO.itmBrandDO;
        Predicate predicate = jpaQDo.isNotNull().or(jpaQDo.isNull());
        ExpressionUtils.and(predicate, jpaQDo.id.eq(id));
        return predicate;
    }

    /**
     * 条件查询
     *
     * @param param 查询条件
     */
    public Predicate where(ItmBrandQueryParam param) {
        val jpaQDo = QItmBrandDO.itmBrandDO;
        Predicate predicate = jpaQDo.isNotNull().or(jpaQDo.isNull());
        if (!StringUtils.isEmpty(param.getId())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.id.eq(param.getId()));
        }
        if (!StringUtils.isEmpty(param.getBrandCode())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandCode.eq(param.getBrandCode()));
        }
        if (!StringUtils.isEmpty(param.getBrandName())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandName.eq(param.getBrandName()));
        }
        if (!StringUtils.isEmpty(param.getBrandName2())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandName2.eq(param.getBrandName2()));
        }
        if (!StringUtils.isEmpty(param.getAbbrName())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.abbrName.eq(param.getAbbrName()));
        }
        if (!StringUtils.isEmpty(param.getBrandStatus())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandStatus.eq(param.getBrandStatus()));
        }
        if (!StringUtils.isEmpty(param.getBrandType())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandType.eq(param.getBrandType()));
        }
        if (!StringUtils.isEmpty(param.getBrandType2())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandType2.eq(param.getBrandType2()));
        }
        if (!StringUtils.isEmpty(param.getBrandType3())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandType3.eq(param.getBrandType3()));
        }
        if (!StringUtils.isEmpty(param.getItemGroup())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.itemGroup.eq(param.getItemGroup()));
        }
        if (!StringUtils.isEmpty(param.getItemCate())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.itemCate.eq(param.getItemCate()));
        }
        if (!StringUtils.isEmpty(param.getBrandPhase())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandPhase.eq(param.getBrandPhase()));
        }
        if (!StringUtils.isEmpty(param.getBrandLevel())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandLevel.eq(param.getBrandLevel()));
        }
        if (!StringUtils.isEmpty(param.getPid())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.pid.eq(param.getPid()));
        }
        if (!StringUtils.isEmpty(param.getBrandPath())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.brandPath.eq(param.getBrandPath()));
        }
        if (!StringUtils.isEmpty(param.getAgency())) {
            predicate = ExpressionUtils.and(predicate, jpaQDo.agency.eq(param.getAgency()));
        }
        return predicate;
    }
}
